@@ -556,7 +556,7 @@ MainWindow::OnMouseDown(PixelScalar x, PixelScalar y)
   if (SingleWindow::OnMouseDown(x, y))
     return true;
 
-  if (!dragging) {
+  if (!dragging && !HasDialog()) {
     dragging = true;
     SetCapture();
     gestures.Start(x, y, Layout::Scale(20));
@@ -693,6 +693,7 @@ MainWindow::OnDestroy()
   timer.Cancel();
 
   KillWidget();
+  KillBottomWidget();
 
   SingleWindow::OnDestroy();
 }
@@ -829,6 +830,18 @@ MainWindow::KillWidget()
   InputEvents::SetFlavour(NULL);
 }
 
+void
+MainWindow::KillBottomWidget()
+{
+  if (bottom_widget == nullptr)
+    return;
+
+  if (widget == nullptr)
+    bottom_widget->Hide();
+  bottom_widget->Unprepare();
+  delete bottom_widget;
+}
+
 void
 MainWindow::SetBottomWidget(Widget *_widget)
 {
@@ -841,12 +854,7 @@ MainWindow::SetBottomWidget(Widget *_widget)
     return;
   }
 
-  if (bottom_widget != nullptr) {
-    if (widget == nullptr)
-      bottom_widget->Hide();
-    bottom_widget->Unprepare();
-    delete bottom_widget;
-  }
+  KillBottomWidget();
 
   bottom_widget = _widget;
 
